==> bulma-tagsinput-1.0.3.tgz: package/README.md <==
# Introduction
This components has been developped as a [Bulma](https://bulma.io) extension and brings **a full-featured user interface for managing tags  supporting autocomplete** to your project.

[![npm](https://img.shields.io/npm/v/@creativebulma/bulma-tagsinput.svg)](https://www.npmjs.com/package/@creativebulma/bulma-tagsinput)
[![npm](https://img.shields.io/npm/dm/@creativebulma/bulma-tagsinput.svg)](https://www.npmjs.com/package/@creativebulma/bulma-tagsinput)
[![](https://data.jsdelivr.com/v1/package/npm/@creativebulma/bulma-tagsinput/badge)](https://www.jsdelivr.com/package/npm/@creativebulma/bulma-tagsinput)

---

## Prerequisites
This component extends [Bulma CSS Framework](https://bulma.io) and requires it to work.

## Get Started
```shell
npm i -D @creativebulma/bulma-tagsinput
```
Full installation steps can be found here: [installation steps](https://demo.creativebulma.net/components/tagsinput/1.0/get-started)

## Documentation & Demo
Full documentation and demo are available [here](https://demo.creativebulma.net/components/tagsinput/1.0/)

## About the project
BulmaTagsInput is © 2020 by [CreativeBulma](https://creativebulma.net).

**If you enjoy this component, have a look at our [MarketPlace](https://creativebulma.net) and discover Free and Premium Bulma components and Templates.**

## License
BulmaTagsInput is distributed under [MIT](https://github.com/CreativeBulma/bulma-tagsinput/blob/master/LICENSE) license.

## Contributing
**Contribution are welcome!**  
You found a bug, a typo issue ? Feel free to create a PR on the [github repository](https://github.com/CreativeBulma/bulma-tagsinput/) of this project.

When contributing to this project, please first discuss the change you wish to make via issue on the [github repository](https://github.com/CreativeBulma/bulma-tagsinput/issues), email, or any other method with the owners of this project before making a change.

==> bulma-tagsinput-1.0.8.tgz: package/README.md <==
# Introduction
This components has been developped as a [Bulma](https://bulma.io) extension and brings **a full-featured user interface for managing tags  supporting autocomplete** to your project.

[![npm](https://img.shields.io/npm/v/@creativebulma/bulma-tagsinput.svg)](https://www.npmjs.com/package/@creativebulma/bulma-tagsinput)
[![npm](https://img.shields.io/npm/dm/@creativebulma/bulma-tagsinput.svg)](https://www.npmjs.com/package/@creativebulma/bulma-tagsinput)
[![](https://data.jsdelivr.com/v1/package/npm/@creativebulma/bulma-tagsinput/badge)](https://www.jsdelivr.com/package/npm/@creativebulma/bulma-tagsinput)

---

## Prerequisites
This component extends [Bulma CSS Framework](https://bulma.io) and requires it to work.

## Get Started
```shell
npm i -D @creativebulma/bulma-tagsinput
```
Full installation steps can be found here: [installation steps](https://bulma-tagsinput.netlify.app/get-started)

## Documentation & Demo
Full documentation and demo are available [here](https://bulma-tagsinput.netlify.app)

## About the project
BulmaTagsInput is © 2020 by [CreativeBulma](https://github.com/CreativeBulma).

## License
BulmaTagsInput is distributed under [MIT](https://github.com/CreativeBulma/bulma-tagsinput/blob/master/LICENSE) license.

## Contributing
**Contribution are welcome!**  
You found a bug, a typo issue ? Feel free to create a PR on the [github repository](https://github.com/CreativeBulma/bulma-tagsinput/) of this project.

When contributing to this project, please first discuss the change you wish to make via issue on the [github repository](https://github.com/CreativeBulma/bulma-tagsinput/issues), email, or any other method with the owners of this project before making a change.
